@@ -2,6 +2,5 @@ import Blog from './helpers/Blog';
 
 
 (function initCMS() {
-  Blog.Article.summary();
-  Blog.Article.summaryTitles();
+  Blog.initAll();
 }());
